<?php

// Functionality for the picture frame configuration page.
// Included in the main page.

include("config.php");

// We always need the database.
$db = new SQLite3("pictures.db");

// Process commands.
if(isset($_GET["cmd"]))
	switch($_GET["cmd"]) {
		case "upload":		/********* User is trying to upload an image. *********/
			$tmpFileName = $_FILES["file"]["tmp_name"];
			
			// Check for errors.
			switch($_FILES["file"]["error"]) {
				case UPLOAD_ERR_OK:
					// Fine. Continue.
					break;
				case UPLOAD_ERR_INI_SIZE:
					$error = "Die Datei ist zu groß für den Server. Bitte vor dem Hochladen mit einem Bildbearbeitungsprogramm verkleinern.";
					break;
				case UPLOAD_ERR_PARTIAL:
					$error = "Die Datei wurde nicht vollständig hochgeladen. Bitte noch einmal versuchen.";
					break;
				case UPLOAD_ERR_NO_FILE:
					$error = "Es wurde keine Datei hochgeladen. Bitte noch einmal versuchen.";
					break;
				default:
					$error = "Beim Hochladen trat ein Fehler auf (".$_FILES["file"]["error"]."). Bitte noch einmal versuchen.";
					break;
			}
			if(!is_uploaded_file($tmpFileName))
				$error = "Beim Hochladen trat ein Fehler auf. Bitte noch einmal versuchen.";
			
			// Process file.
			if(!isset($error)) {
				list($width,$height) = @getimagesize($tmpFileName);
				if($width * $height > $maxMegapixels * 1024 * 1024)
					$error = "Das Bild ist zu groß für den Server. Bitte zuerst mit einem Bearbeitungsprogramm verkleinern.";
				else if($width<=0 && $height<=0)
					$error = "Das Bild ist leer. Bitte noch einmal versuchen.";
				else {
					$image = @imagecreatefromjpeg($tmpFileName);
					if(!$image)
						$error = "Beim Bearbeiten des Bilds trat ein Fehler auf. Das Bild ist möglicherweise kein JPEG.";
					else {
						// Insert image and determine ID.
						$time = time();
						$db->exec("insert into pictures(status,date_changed) values('L',$time)");
						$id = $db->lastInsertRowID();
						
						// Create a thumbnail.
						$targetWidth = 200;
						$targetHeight = $height * $targetWidth / $width;
						$thumbnail = @imagecreatetruecolor($targetWidth,$targetHeight);
						if(!$thumbnail) {
							$db->exec("delete from pictures where id = $id");
							die("Not enough server memory for thumbnail.");
						}
						imagecopyresampled($thumbnail,$image,0,0,0,0,$targetWidth,$targetHeight,$width,$height);
						imagejpeg($thumbnail,"pictures/t$id.jpg");
						imagedestroy($thumbnail);
						
						// Create a resized version.
						$targetWidth = $frameWidth;
						$targetHeight = $height * $targetWidth / $width;
						if($targetHeight > $frameHeight) {
							$targetHeight = $frameHeight;
							$targetWidth = $width * $targetHeight / $height;
						}
						$resized = @imagecreatetruecolor($targetWidth,$targetHeight);
						if(!$resized) {
							$db->exec("delete from pictures where id = $id");
							die("Not enough server memory for target image.");
						}
						imagecopyresampled($resized,$image,0,0,0,0,$targetWidth,$targetHeight,$width,$height);
						imagejpeg($resized,"pictures/$id.jpg",90);
						imagedestroy($resized);
						
						$message = "Das Bild wurde erfolgreich hochgeladen und wird auf dem Bilderrahmen angezeigt.";
					}
				}
			}
			break;
		case "remove":		/********* Move image to archive. *********/
			$id = $_GET["id"];
			if(!is_numeric($id))
				die("Incorrect image ID.");
			$db->exec("update pictures set status = 'A',date_changed = ".time()." where id = $id");
			$message = "Das Bild wird nicht mehr auf dem Bilderrahmen angezeigt.";
			break;
		case "add":		/********* Move image to frame. *********/
			$id = $_GET["id"];
			if(!is_numeric($id))
				die("Incorrect image ID.");
			$db->exec("update pictures set status = 'L',date_changed = ".time()." where id = $id");
			$message = "Das Bild wird ab sofort auf dem Bilderrahmen angezeigt.";
			break;
		case "delete":		/********* Delete image permanently. *********/
			$id = $_GET["id"];
			if(!is_numeric($id))
				die("Incorrect image ID.");
			$db->exec("update pictures set status = 'D',date_changed = ".time()." where id = $id");
			$message = "Das Bild wurde gelöscht.";
			break;
		default:
			die("Unknown command.");
	}
	
?>
